searchData={"items":[{"type":"module","title":"HTTPSpec","doc":"Provides implementation-independent HTTP-related structs.","ref":"HTTPSpec.html"},{"type":"module","title":"Why? - HTTPSpec","doc":"Almost every HTTP client has its own abstractions for request and response.\nThese abstractions are enough when solving problems with a particular HTTP\nclient. But, when you are building a package involving HTTP and do not want\nto be tied to a specific HTTP client, these abstractions become limiting.\n\nHTTP clients come and go, but HTTP standards endure forever. It's better to\nbuild around something that is almost unchanging, rather than something\nthat frequently changes.\n\nThis package try to provide implementation-independent HTTP-related structs.\nWith these structs, you can build things involving HTTP, but no actual HTTP\nrequest-response handling is required.","ref":"HTTPSpec.html#module-why"},{"type":"module","title":"Structs - HTTPSpec","doc":"* `HTTPSpec.Request`\n  * `HTTPSpec.Response`","ref":"HTTPSpec.html#module-structs"},{"type":"module","title":"Usage - HTTPSpec","doc":"Build a request struct:\n\n    HTTPSpec.Request.new(options)\n    HTTPSpec.Request.new!(options)\n\nBuild a response struct:\n\n    HTTPSpec.Response.new(options)\n    HTTPSpec.Response.new!(options)\n\nCheck out their docs for more available functionalities.","ref":"HTTPSpec.html#module-usage"},{"type":"module","title":"HTTPSpec.Request","doc":"A struct for describing HTTP request.","ref":"HTTPSpec.Request.html"},{"type":"function","title":"HTTPSpec.Request.build_method/1","doc":"Builds a method.","ref":"HTTPSpec.Request.html#build_method/1"},{"type":"function","title":"Examples - HTTPSpec.Request.build_method/1","doc":"iex> request = Request.new!([method: :post, ...])\n    iex> Request.build_method(request)\n    \"POST\"\n\n    iex> request = Request.new!(method: \"POST\", ...)\n    iex> Request.build_method(request)\n    \"POST\"","ref":"HTTPSpec.Request.html#build_method/1-examples"},{"type":"function","title":"HTTPSpec.Request.build_url/1","doc":"Builds an URL.","ref":"HTTPSpec.Request.html#build_url/1"},{"type":"function","title":"Examples - HTTPSpec.Request.build_url/1","doc":"iex> request = Request.new!(\n    ...>   method: :get\n    ...>   scheme: :https,\n    ...>   host: \"www.example.com\",\n    ...>   port: 443,\n    ...>   path: \"/image.png\",\n    ...>   query: \"size=lg\",\n    ...>   fragment: \"124,28\"\n    ...> )\n    iex> Request.build_url(request)\n    \"https://www.example.com/image.png?size=lg#124,28\"","ref":"HTTPSpec.Request.html#build_url/1-examples"},{"type":"function","title":"HTTPSpec.Request.delete_header/2","doc":"Deletes the header given by `name`.\n\nAll occurrences of the header are deleted, in case the header is repeated multiple times.","ref":"HTTPSpec.Request.html#delete_header/2"},{"type":"function","title":"Examples - HTTPSpec.Request.delete_header/2","doc":"iex> Request.get_header(request, \"cache-control\")\n    [\"max-age=600\", \"no-transform\"]\n    iex> request = Request.delete_header(req, \"cache-control\")\n    iex> Request.get_header(request, \"cache-control\")\n    []","ref":"HTTPSpec.Request.html#delete_header/2-examples"},{"type":"function","title":"HTTPSpec.Request.get_header/2","doc":"Returns the values of the header specified by `name`.","ref":"HTTPSpec.Request.html#get_header/2"},{"type":"function","title":"Examples - HTTPSpec.Request.get_header/2","doc":"iex> Request.get_header(request, \"accept\")\n    [\"application/json\"]\n    iex> Request.get_header(requset, \"x-unknown\")\n    []","ref":"HTTPSpec.Request.html#get_header/2-examples"},{"type":"function","title":"HTTPSpec.Request.new/1","doc":"","ref":"HTTPSpec.Request.html#new/1"},{"type":"function","title":"HTTPSpec.Request.new!/1","doc":"","ref":"HTTPSpec.Request.html#new!/1"},{"type":"function","title":"HTTPSpec.Request.put_header/3","doc":"Puts a request header `name` to `value`.\n\nIf the header was previously set, its value is overwritten.","ref":"HTTPSpec.Request.html#put_header/3"},{"type":"function","title":"Examples - HTTPSpec.Request.put_header/3","doc":"iex> Request.get_header(request, \"accept\")\n    []\n    iex> request = Request.put_header(request, \"accept\", \"application/json\")\n    iex> Request.get_header(request, \"accept\")\n    [\"application/json\"]","ref":"HTTPSpec.Request.html#put_header/3-examples"},{"type":"function","title":"HTTPSpec.Request.put_new_header/3","doc":"Puts a request header `name` to `value` unless already present.\n\nSee `put_header/3` for more information.","ref":"HTTPSpec.Request.html#put_new_header/3"},{"type":"function","title":"Examples - HTTPSpec.Request.put_new_header/3","doc":"iex> request =\n    ...>   request\n    ...>   |> Request.put_new_header(\"accept\", \"application/json\")\n    ...>   |> Request.put_new_header(\"accept\", \"text/html\")\n    iex> Request.get_header(request, \"accept\")\n    [\"application/json\"]","ref":"HTTPSpec.Request.html#put_new_header/3-examples"},{"type":"type","title":"HTTPSpec.Request.body/0","doc":"","ref":"HTTPSpec.Request.html#t:body/0"},{"type":"type","title":"HTTPSpec.Request.fragment/0","doc":"","ref":"HTTPSpec.Request.html#t:fragment/0"},{"type":"type","title":"HTTPSpec.Request.headers/0","doc":"","ref":"HTTPSpec.Request.html#t:headers/0"},{"type":"type","title":"HTTPSpec.Request.host/0","doc":"","ref":"HTTPSpec.Request.html#t:host/0"},{"type":"type","title":"HTTPSpec.Request.method/0","doc":"","ref":"HTTPSpec.Request.html#t:method/0"},{"type":"type","title":"HTTPSpec.Request.path/0","doc":"","ref":"HTTPSpec.Request.html#t:path/0"},{"type":"type","title":"HTTPSpec.Request.query/0","doc":"","ref":"HTTPSpec.Request.html#t:query/0"},{"type":"type","title":"HTTPSpec.Request.scheme/0","doc":"","ref":"HTTPSpec.Request.html#t:scheme/0"},{"type":"type","title":"HTTPSpec.Request.t/0","doc":"","ref":"HTTPSpec.Request.html#t:t/0"},{"type":"module","title":"HTTPSpec.Response","doc":"A struct for describing HTTP response.","ref":"HTTPSpec.Response.html"},{"type":"function","title":"HTTPSpec.Response.get_header/2","doc":"Returns the values of the header specified by `name`.","ref":"HTTPSpec.Response.html#get_header/2"},{"type":"function","title":"Examples - HTTPSpec.Response.get_header/2","doc":"iex> Response.get_header(response, \"content-type\")\n    [\"application/json\"]\n\n    iex> Response.get_header(response, \"x-unknown\")\n    []","ref":"HTTPSpec.Response.html#get_header/2-examples"},{"type":"function","title":"HTTPSpec.Response.get_trailer/2","doc":"Returns the values of the trailer specified by `name`.","ref":"HTTPSpec.Response.html#get_trailer/2"},{"type":"function","title":"Examples - HTTPSpec.Response.get_trailer/2","doc":"iex> Response.get_trailer(response, \"expires\")\n    [\"Wed, 21 Oct 2015 07:28:00 GMT\"]\n\n    iex> Response.get_trailer(response, \"x-unknown\")\n    []","ref":"HTTPSpec.Response.html#get_trailer/2-examples"},{"type":"function","title":"HTTPSpec.Response.new/1","doc":"","ref":"HTTPSpec.Response.html#new/1"},{"type":"function","title":"HTTPSpec.Response.new!/1","doc":"","ref":"HTTPSpec.Response.html#new!/1"},{"type":"type","title":"HTTPSpec.Response.body/0","doc":"","ref":"HTTPSpec.Response.html#t:body/0"},{"type":"type","title":"HTTPSpec.Response.headers/0","doc":"","ref":"HTTPSpec.Response.html#t:headers/0"},{"type":"type","title":"HTTPSpec.Response.status/0","doc":"","ref":"HTTPSpec.Response.html#t:status/0"},{"type":"type","title":"HTTPSpec.Response.t/0","doc":"","ref":"HTTPSpec.Response.html#t:t/0"},{"type":"exception","title":"HTTPSpec.ArgumentError","doc":"An error that is returned (or raised) when given options are invalid.","ref":"HTTPSpec.ArgumentError.html"},{"type":"type","title":"HTTPSpec.ArgumentError.t/0","doc":"","ref":"HTTPSpec.ArgumentError.html#t:t/0"},{"type":"extras","title":"HTTPSpec","doc":"# HTTPSpec\n\n[![CI](https://github.com/cozy-elixir/http_spec/actions/workflows/ci.yml/badge.svg)](https://github.com/cozy-elixir/http_spec/actions/workflows/ci.yml)\n[![Hex.pm](https://img.shields.io/hexpm/v/http_spec.svg)](https://hex.pm/packages/http_spec)\n\nProvides implementation-independent HTTP-related structs.","ref":"readme.html"},{"type":"extras","title":"Installation - HTTPSpec","doc":"Add `:http_spec` to the list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:http_spec,  }\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - HTTPSpec","doc":"For more information, see the [documentation](https://hexdocs.pm/http_spec).","ref":"readme.html#usage"},{"type":"extras","title":"Thanks - HTTPSpec","doc":"- [wojtekmach/req](https://github.com/wojtekmach/req)\n- [inets/httpc from Erlang](https://www.erlang.org/doc/apps/inets/httpc)","ref":"readme.html#thanks"},{"type":"extras","title":"License - HTTPSpec","doc":"[Apache License 2.0](http://www.apache.org/licenses/LICENSE-2.0)","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"2.0.0 - Changelog","doc":"","ref":"changelog.html#2-0-0"},{"type":"extras","title":"Breaking changes - Changelog","doc":"- rename `build/1` to `new/1`\n- rename `build!/1` to `new!/1`\n- downcase header names when building a `%HTTPSpec.Response{}`","ref":"changelog.html#breaking-changes"},{"type":"extras","title":"New features - Changelog","doc":"- add `HTTPSpec.Request.build_method/1`\n- add `HTTPSpec.Request.build_url/1`\n- add `HTTPSpec.Response.get_trailer/2`","ref":"changelog.html#new-features"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,49]}}